@@ -38,6 +38,22 @@ class Cubeviz(ConfigHelper, LineListMixin):
             else:
                 viewer.state.x_att_pixel = ref_data.id["Pixel Axis 2 [x]"]
 
+    def load_data(self, data, **kwargs):
+        """
+        Load and parse a data cube with Cubeviz.
+        (Note that only one cube may be loaded per Cubeviz instance.)
+
+        Parameters
+        ----------
+        data : str or `~astropy.io.fits.HDUList`
+            A string file path or astropy FITS object pointing to the
+            data cube.
+        """
+        if len(self.app.state.data_items) != 0:
+            raise RuntimeError('only one cube may be loaded per Cubeviz instance')
+
+        super().load_data(data, parser_reference="cubeviz-data-parser", **kwargs)
+
     def select_slice(self, slice):
         """
         Select a slice by index.
