@@ -102,6 +102,7 @@ class ImvizImageView(BqplotImageView, AstrowidgetsImageViewerMixin, JdavizViewer
             # Extract first dataset from visible layers and use this for coordinates - the choice
             # of dataset shouldn't matter if the datasets are linked correctly
             image = active_layer.layer
+            self.label_mouseover.icon = self.jdaviz_app.state.layer_icons.get(active_layer.layer.label)  # noqa
 
             # Extract data coordinates - these are pixels in the reference image
             x = data['domain']['x']
@@ -119,8 +120,12 @@ class ImvizImageView(BqplotImageView, AstrowidgetsImageViewerMixin, JdavizViewer
             self.label_mouseover.pixel = (fmt.format(x, y))
 
             if coords_status:
-                coo = image.coords.pixel_to_world(x, y).icrs
-                self.label_mouseover.set_coords(coo)
+                try:
+                    coo = image.coords.pixel_to_world(x, y).icrs
+                except Exception:  # WCS might not be celestial
+                    self.label_mouseover.reset_coords_display()
+                else:
+                    self.label_mouseover.set_coords(coo)
             else:
                 self.label_mouseover.reset_coords_display()
 
