@@ -2,7 +2,7 @@ import numpy as np
 import warnings
 
 from glue.core import BaseData
-from glue.core.subset import Subset
+from glue.core.subset import Subset, RoiSubsetState
 from glue.config import data_translator
 from glue_jupyter.bqplot.profile import BqplotProfileView
 from glue.core.exceptions import IncompatibleAttribute
@@ -30,17 +30,17 @@ class SpecvizProfileView(BqplotProfileView, JdavizViewerMixin):
     # ones are added in glue-jupyter in future that we don't want here.
     inherit_tools = False
 
-    tools = ['bqplot:home',
+    tools = ['jdaviz:homezoom',
              'jdaviz:boxzoom', 'jdaviz:xrangezoom',
-             'bqplot:panzoom', 'bqplot:panzoom_x',
-             'bqplot:panzoom_y', 'bqplot:xrange',
+             'jdaviz:panzoom', 'jdaviz:panzoom_x',
+             'jdaviz:panzoom_y', 'bqplot:xrange',
              'jdaviz:selectline']
 
     # categories: zoom resets, zoom, pan, subset, select tools, shortcuts
     tools_nested = [
-                    ['bqplot:home'],
-                    ['jdaviz:xrangezoom', 'jdaviz:boxzoom'],
-                    ['bqplot:panzoom', 'bqplot:panzoom_x', 'bqplot:panzoom_y'],
+                    ['jdaviz:homezoom', 'jdaviz:prevzoom'],
+                    ['jdaviz:boxzoom', 'jdaviz:xrangezoom'],
+                    ['jdaviz:panzoom', 'jdaviz:panzoom_x', 'jdaviz:panzoom_y'],
                     ['bqplot:xrange'],
                     ['jdaviz:selectline'],
                     ['jdaviz:sidebar_plot', 'jdaviz:sidebar_export']
@@ -52,26 +52,24 @@ class SpecvizProfileView(BqplotProfileView, JdavizViewerMixin):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        self._subscribe_to_layers_update()
         self._initialize_toolbar_nested(default_tool_priority=['jdaviz:selectslice'])
         self._offscreen_lines_marks = OffscreenLinesMarks(self)
         self.figure.marks = self.figure.marks + self._offscreen_lines_marks.marks
 
-        self.display_uncertainties = False
+        self.state.add_callback('show_uncertainty', self._show_uncertainty_changed)
+
         self.display_mask = False
 
         # Change collapse function to sum
         self.state.function = 'sum'
 
-    def _on_subset_create(self, msg):
-        for layer in self.state.layers:
-            if layer.layer.label == msg.subset.label:
-                layer.linewidth = 3
-
-    def _on_add_data(self, msg):
-        data_label = msg.data.label
-        for layer in self.state.layers:
-            if "Subset" in layer.layer.label and layer.layer.data.label == data_label:
-                layer.linewidth = 3
+    def _expected_subset_layer_default(self, layer):
+        super()._expected_subset_layer_default(layer)
+        if isinstance(layer.layer.subset_state, RoiSubsetState):
+            layer.linewidth = 1
+        else:
+            layer.linewidth = 3
 
     def data(self, cls=None):
         # Grab the user's chosen statistic for collapsing data
@@ -318,22 +316,26 @@ class SpecvizProfileView(BqplotProfileView, JdavizViewerMixin):
     def available_linelists(self):
         return get_available_linelists()
 
-    def show_uncertainties(self):
-        self.display_uncertainties = True
-        self._plot_uncertainties()
+    def _show_uncertainty_changed(self, msg=None):
+        # this is subscribed in init to watch for changes to the state
+        # object since uncertainty handling is in jdaviz instead of glue/glue-jupyter
+        if self.state.show_uncertainty:
+            self._plot_uncertainties()
+        else:
+            self._clean_error()
 
     def show_mask(self):
         self.display_mask = True
         self._plot_mask()
 
     def clean(self):
-        self.display_uncertainties = False
-        self.display_mask = False
-
         # Remove extra traces, in case they exist.
-        self._clean_error()
+        self.display_mask = False
         self._clean_mask()
 
+        # this will automatically call _clean_error via _show_uncertainty_changed
+        self.state.show_uncertainty = False
+
     def _clean_mask(self):
         fig = self.figure
         fig.marks = [x for x in fig.marks if not isinstance(x, ScatterMask)]
@@ -369,6 +371,14 @@ class SpecvizProfileView(BqplotProfileView, JdavizViewerMixin):
 
         self._plot_mask()
 
+        # Set default linewidth on any created spectral subset layers
+        # NOTE: this logic will need updating if we add support for multiple cubes as this assumes
+        # that new data entries (from model fitting or gaussian smooth, etc) will only be spectra
+        # and all subsets affected will be spectral
+        for layer in self.state.layers:
+            if "Subset" in layer.layer.label and layer.layer.data.label == data.label:
+                layer.linewidth = 3
+
         return result
 
     def _plot_mask(self):
@@ -414,7 +424,7 @@ class SpecvizProfileView(BqplotProfileView, JdavizViewerMixin):
                 self.figure.marks = list(self.figure.marks) + [mask_line_mark]
 
     def _plot_uncertainties(self):
-        if not self.display_uncertainties:
+        if not self.state.show_uncertainty:
             return
 
         # Remove existing error bars
