@@ -21,10 +21,6 @@ ICON_DIR = os.path.join(os.path.dirname(__file__), '..', 'data', 'icons')
 
 
 # Override icons for built-in tools from glue-jupyter
-HomeTool.icon = os.path.join(ICON_DIR, 'home.svg')
-BqplotPanZoomMode.icon = os.path.join(ICON_DIR, 'pan.svg')
-BqplotPanZoomXMode.icon = os.path.join(ICON_DIR, 'pan_x.svg')
-BqplotPanZoomYMode.icon = os.path.join(ICON_DIR, 'pan_y.svg')
 BqplotRectangleMode.icon = os.path.join(ICON_DIR, 'select_xy.svg')
 BqplotCircleMode.icon = os.path.join(ICON_DIR, 'select_circle.svg')
 BqplotEllipseMode.icon = os.path.join(ICON_DIR, 'select_ellipse.svg')
@@ -32,7 +28,72 @@ BqplotXRangeMode.icon = os.path.join(ICON_DIR, 'select_x.svg')
 BqplotYRangeMode.icon = os.path.join(ICON_DIR, 'select_y.svg')
 
 
-class _BaseSelectZoom(BqplotSelectionTool):
+class _BaseZoomHistory:
+    # Mixin for custom zoom tools to be able to save their previous zoom state
+    # which is then used by the PrevZoom tool
+    def save_prev_zoom(self):
+        self.viewer._prev_limits = (self.viewer.state.x_min, self.viewer.state.x_max,
+                                    self.viewer.state.y_min, self.viewer.state.y_max)
+
+
+@viewer_tool
+class PrevZoom(Tool, _BaseZoomHistory):
+    icon = os.path.join(ICON_DIR, 'zoom_back.svg')
+    tool_id = 'jdaviz:prevzoom'
+    action_text = 'Previous zoom'
+    tool_tip = 'Back to previous zoom level'
+
+    def activate(self):
+        if self.viewer._prev_limits is None:
+            return
+        prev_limits = self.viewer._prev_limits
+        self.save_prev_zoom()
+        self.viewer.state.x_min, self.viewer.state.x_max, self.viewer.state.y_min, self.viewer.state.y_max = prev_limits  # noqa
+
+
+@viewer_tool
+class HomeZoom(HomeTool, _BaseZoomHistory):
+    icon = os.path.join(ICON_DIR, 'home.svg')
+    tool_id = 'jdaviz:homezoom'
+    action_text = 'Reset zoom'
+    tool_tip = 'Reset zoom to show all visible data'
+
+    def activate(self):
+        self.save_prev_zoom()
+        super().activate()
+
+
+@viewer_tool
+class PanZoom(BqplotPanZoomMode, _BaseZoomHistory):
+    icon = os.path.join(ICON_DIR, 'pan.svg')
+    tool_id = 'jdaviz:panzoom'
+
+    def activate(self):
+        self.save_prev_zoom()
+        super().activate()
+
+
+@viewer_tool
+class PanZoomX(BqplotPanZoomXMode, _BaseZoomHistory):
+    icon = os.path.join(ICON_DIR, 'pan_x.svg')
+    tool_id = 'jdaviz:panzoom_x'
+
+    def activate(self):
+        self.save_prev_zoom()
+        super().activate()
+
+
+@viewer_tool
+class PanZoomY(BqplotPanZoomYMode, _BaseZoomHistory):
+    icon = os.path.join(ICON_DIR, 'pan_y.svg')
+    tool_id = 'jdaviz:panzoom_y'
+
+    def activate(self):
+        self.save_prev_zoom()
+        super().activate()
+
+
+class _BaseSelectZoom(BqplotSelectionTool, _BaseZoomHistory):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.reset()
@@ -51,6 +112,8 @@ class _BaseSelectZoom(BqplotSelectionTool):
             # start drawing a box, don't need to do anything
             return
 
+        self.save_prev_zoom()
+
         with delay_callback(self.viewer.state, 'x_min', 'x_max', 'y_min', 'y_max'):
             # implement on_update_zoom to act on the applicable interact Selector
             self.on_update_zoom()
@@ -145,8 +208,8 @@ class SelectLine(CheckableTool, HubListener):
 
 
 class _BaseSidebarShortcut(Tool):
-    plugin_label = None  # define in subclass
-    viewer_select_traitlet = 'viewer_selected'
+    plugin_name = None  # define in subclass
+    viewer_attr = 'viewer'
 
     def activate(self):
         jdaviz_state = self.viewer.jdaviz_app.state
@@ -156,13 +219,16 @@ class _BaseSidebarShortcut(Tool):
         if index not in jdaviz_state.tray_items_open:
             jdaviz_state.tray_items_open = jdaviz_state.tray_items_open + [index]
         plugin = self.viewer.jdaviz_app.get_tray_item_from_name(self.plugin_name)
-        setattr(plugin, self.viewer_select_traitlet, self.viewer.reference_id)
+        viewer_id = self.viewer.reference_id
+        viewer_select = getattr(plugin, self.viewer_attr)
+        if viewer_select.multiselect:
+            viewer_id = [viewer_id]
+        setattr(viewer_select, 'selected', viewer_id)
 
 
 @viewer_tool
 class SidebarShortcutPlotOptions(_BaseSidebarShortcut):
     plugin_name = 'g-plot-options'
-    viewer_select_traitlet = 'viewer_selected'
 
     icon = os.path.join(ICON_DIR, 'tune.svg')
     tool_id = 'jdaviz:sidebar_plot'
@@ -173,7 +239,6 @@ class SidebarShortcutPlotOptions(_BaseSidebarShortcut):
 @viewer_tool
 class SidebarShortcutExportPlot(_BaseSidebarShortcut):
     plugin_name = 'g-export-plot'
-    viewer_select_traitlet = 'viewer_selected'
 
     icon = os.path.join(ICON_DIR, 'image.svg')
     tool_id = 'jdaviz:sidebar_export'
@@ -184,7 +249,6 @@ class SidebarShortcutExportPlot(_BaseSidebarShortcut):
 @viewer_tool
 class SidebarShortcutCompass(_BaseSidebarShortcut):
     plugin_name = 'imviz-compass'
-    viewer_select_traitlet = 'viewer_selected'
 
     icon = os.path.join(ICON_DIR, 'compass.svg')
     tool_id = 'jdaviz:sidebar_compass'
